@@ -230,6 +230,8 @@ class Simile:
     async def create_agent(
         self,
         name: str,
+        source: Optional[str] = None,
+        source_id: Optional[str] = None,
         population_id: Optional[Union[str, uuid.UUID]] = None,
         agent_data: Optional[List[Dict[str, Any]]] = None,
     ) -> AgentModel:
